from FinNews.feed import Feed
from FinNews.cnbc import CNBC
from FinNews.seeking_alpha import SeekingAlpha
from FinNews.investing import Investing
from FinNews.wsj import WSJ
from FinNews.yahoo import Yahoo

name = "FinNews"

__version__ = "0.8.1"

__all__ = ['Feed', 'CNBC', 'SeekingAlpha', 'Investing', 'WSJ', 'Yahoo']
